@@ -47,6 +47,7 @@ struct _XfceRRMode
     guint width;
     guint height;
     gdouble rate;
+    XRRModeFlags flags;
 };
 
 struct _XfceOutputPosition
@@ -144,6 +145,9 @@ xfce_randr_mode_height (XfceRandr *randr,
                         guint output,
                         const XfceRRMode *mode);
 
+gdouble
+xfce_randr_calculate_refresh_rate (XRRModeInfo mode);
+
 G_END_DECLS
 
 #endif /* !__XFCE_RANDR_H__ */
