@@ -21,8 +21,6 @@
 #include "config.h"
 #endif
 
-#include "accessibility-dialog_ui.h"
-
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <gtk/gtkx.h>
@@ -208,7 +206,7 @@ main (gint argc,
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2008-2025");
+        g_print ("%s\n", "Copyright (c) 2008-" COPYRIGHT_YEAR);
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
@@ -242,9 +240,7 @@ main (gint argc,
 
     /* load the Gtk user-interface file */
     builder = gtk_builder_new ();
-    if (gtk_builder_add_from_string (builder, accessibility_dialog_ui,
-                                     accessibility_dialog_ui_length, &error)
-        != 0)
+    if (gtk_builder_add_from_resource (builder, "/org/xfce/settings/accessibility-dialog.glade", &error) != 0)
     {
         /* Configure widgets */
         accessibility_settings_dialog_configure_widgets (builder);
