@@ -22,7 +22,6 @@
 #endif
 
 #include "color-device.h"
-#include "color-dialog_ui.h"
 #include "color-profile.h"
 
 #include <libxfce4ui/libxfce4ui.h>
@@ -1479,7 +1478,7 @@ main (gint argc,
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2008-2025");
+        g_print ("%s\n", "Copyright (c) 2008-" COPYRIGHT_YEAR);
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
@@ -1493,7 +1492,7 @@ main (gint argc,
 
     /* load the Gtk user-interface file */
     builder = gtk_builder_new ();
-    if (gtk_builder_add_from_string (builder, color_dialog_ui, color_dialog_ui_length, &error) != 0)
+    if (gtk_builder_add_from_resource (builder, "/org/xfce/settings/color-dialog.glade", &error) != 0)
     {
         /* Initialize the dialog */
         settings = color_settings_dialog_init (builder);
