@@ -21,8 +21,6 @@
 #include "config.h"
 #endif
 
-#include "mouse-dialog_ui.h"
-
 #include "xfsettingsd/pointers-defines.h"
 
 #include <cairo-gobject.h>
@@ -2211,7 +2209,7 @@ main (gint argc,
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2004-2025");
+        g_print ("%s\n", "Copyright (c) 2004-" COPYRIGHT_YEAR);
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
@@ -2270,9 +2268,7 @@ main (gint argc,
     {
         /* load the Gtk+ user-interface file */
         builder = gtk_builder_new ();
-        if (gtk_builder_add_from_string (builder, mouse_dialog_ui,
-                                         mouse_dialog_ui_length, &error)
-            != 0)
+        if (gtk_builder_add_from_resource (builder, "/org/xfce/settings/mouse-dialog.glade", &error) != 0)
         {
             /* lock */
             locked++;
