@@ -62,8 +62,8 @@ save_window_size (GtkWidget *dialog,
     {
         /* save window size */
         gtk_window_get_size (GTK_WINDOW (dialog), &width, &height);
-        xfconf_channel_set_int (channel, "/last/window-width", width),
-            xfconf_channel_set_int (channel, "/last/window-height", height);
+        xfconf_channel_set_int (channel, "/last/window-width", width);
+        xfconf_channel_set_int (channel, "/last/window-height", height);
         xfconf_channel_set_int (channel, "/last/paned-position", paned_pos);
     }
 }
@@ -133,7 +133,7 @@ main (gint argc,
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2008-2025");
+        g_print ("%s\n", "Copyright (c) 2008-" COPYRIGHT_YEAR);
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
